"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseBlockId = exports.EthCallQueryRequest = void 0;
const buffer_1 = require("buffer");
const BinaryWriter_1 = require("./BinaryWriter");
const request_1 = require("./request");
const utils_1 = require("./utils");
class EthCallQueryRequest {
    constructor(blockTag, callData) {
        this.callData = callData;
        this.blockTag = parseBlockId(blockTag);
    }
    type() {
        return request_1.ChainQueryType.EthCall;
    }
    serialize() {
        const writer = new BinaryWriter_1.BinaryWriter()
            .writeUint32(this.blockTag.length)
            .writeUint8Array(buffer_1.Buffer.from(this.blockTag))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = (0, utils_1.hexToUint8Array)(data);
            writer
                .writeUint8Array((0, utils_1.hexToUint8Array)(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
}
exports.EthCallQueryRequest = EthCallQueryRequest;
function parseBlockId(blockId) {
    if (!blockId || blockId === "") {
        throw new Error(`block tag is required`);
    }
    if (typeof blockId === "number") {
        if (blockId < 0) {
            throw new Error(`block tag must be positive`);
        }
        blockId = `0x${blockId.toString(16)}`;
    }
    else if ((0, utils_1.isValidHexString)(blockId)) {
        if (!blockId.startsWith("0x")) {
            blockId = `0x${blockId}`;
        }
    }
    else {
        throw new Error(`Invalid block tag: ${blockId}`);
    }
    return blockId;
}
exports.parseBlockId = parseBlockId;
