"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EthCallWithFinalityQueryRequest = void 0;
const BinaryWriter_1 = require("./BinaryWriter");
const ethCall_1 = require("./ethCall");
const request_1 = require("./request");
const utils_1 = require("./utils");
class EthCallWithFinalityQueryRequest {
    constructor(blockId, finality, callData) {
        this.callData = callData;
        this.blockId = (0, ethCall_1.parseBlockId)(blockId);
        this.finality = finality;
    }
    type() {
        return request_1.ChainQueryType.EthCallWithFinality;
    }
    serialize() {
        const writer = new BinaryWriter_1.BinaryWriter()
            .writeUint32(this.blockId.length)
            .writeUint8Array(Buffer.from(this.blockId))
            .writeUint32(this.finality.length)
            .writeUint8Array(Buffer.from(this.finality))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = (0, utils_1.hexToUint8Array)(data);
            writer
                .writeUint8Array((0, utils_1.hexToUint8Array)(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
}
exports.EthCallWithFinalityQueryRequest = EthCallWithFinalityQueryRequest;
