import { Buffer } from "buffer";
import { BinaryWriter } from "./BinaryWriter";
import { ChainQueryType } from "./request";
import { hexToUint8Array, isValidHexString } from "./utils";
export class EthCallQueryRequest {
    constructor(blockTag, callData) {
        this.callData = callData;
        this.blockTag = parseBlockId(blockTag);
    }
    type() {
        return ChainQueryType.EthCall;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint32(this.blockTag.length)
            .writeUint8Array(Buffer.from(this.blockTag))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = hexToUint8Array(data);
            writer
                .writeUint8Array(hexToUint8Array(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
}
export function parseBlockId(blockId) {
    if (!blockId || blockId === "") {
        throw new Error(`block tag is required`);
    }
    if (typeof blockId === "number") {
        if (blockId < 0) {
            throw new Error(`block tag must be positive`);
        }
        blockId = `0x${blockId.toString(16)}`;
    }
    else if (isValidHexString(blockId)) {
        if (!blockId.startsWith("0x")) {
            blockId = `0x${blockId}`;
        }
    }
    else {
        throw new Error(`Invalid block tag: ${blockId}`);
    }
    return blockId;
}
