import { BinaryWriter } from "./BinaryWriter";
import { parseBlockId } from "./ethCall";
import { ChainQueryType } from "./request";
import { hexToUint8Array } from "./utils";
export class EthCallWithFinalityQueryRequest {
    constructor(blockId, finality, callData) {
        this.callData = callData;
        this.blockId = parseBlockId(blockId);
        this.finality = finality;
    }
    type() {
        return ChainQueryType.EthCallWithFinality;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint32(this.blockId.length)
            .writeUint8Array(Buffer.from(this.blockId))
            .writeUint32(this.finality.length)
            .writeUint8Array(Buffer.from(this.finality))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = hexToUint8Array(data);
            writer
                .writeUint8Array(hexToUint8Array(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
}
